==> spip_4.0.4.orig.tar.xz: plugins-dist/forum/lang/forum_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=lb
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_message_forum' => 'Kee Message am Forum',

	// B
	'bouton_radio_articles_futurs' => 'nëmmen fir nei Artikelen (keng Aktioun op d’Datebank).',
	'bouton_radio_articles_tous' => 'fir all nei Artikelen ouni Ausnahm.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'fir all Artikelen, ausser déi wou de Forum ausgeschalt ass.',
	'bouton_radio_enregistrement_obligatoire' => 'Obligatorescht Aschreiwen (d’Benotzer mussen sech umellen andeem si hier Email-Adress uginn ier se hier Message kënne schécken).',
	'bouton_radio_moderation_priori' => 'Moderatioun à priori (d’Message ginn eréischt verëffentlecht nodeems se vun engem Administrateur bestätegt goufen).',
	'bouton_radio_modere_abonnement' => 'op Abonnement',
	'bouton_radio_modere_posteriori' => 'Moderatioun à posteriori',
	'bouton_radio_modere_priori' => 'Moderatioun à priori',
	'bouton_radio_publication_immediate' => 'Direkt Verëffentlechung vun de Messagen (d’Message ginn direkt nom Schécken siichtbar, d’Administrateure kënnen se duerno läschen).',

	// D
	'documents_interdits_forum' => 'Dokumenter sinn am Forum net erlaabt',

	// E
	'erreur_enregistrement_message' => 'Äre Message konnt duerch en technesche Problem net gespäichert ginn',

	// F
	'form_pet_message_commentaire' => 'E Message, e Kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Dir hutt keen Zougang méi zu dëse Forumen.',
	'forum_attention_dix_caracteres' => '<b>Opgepasst!</b> Äre Message muss op mannst 10 Buschtawen hunn.',
	'forum_attention_message_non_poste' => 'Opgepasst, dir hutt äre Message net fortgeschéckt!',
	'forum_attention_nb_caracteres_mini' => '<b>Opgepasst!</b> Äre Message muss mindestens @min@ Buschtawen hunn.',
	'forum_attention_trois_caracteres' => '<b>Opgepasst!</b> Ären Titel muss op mannst 3 Buschtawen hunn.',
	'forum_attention_trop_caracteres' => '<b>Opgepasst!</b> Äre Message ass ze laang (@compte@ Buschtawen). Fir gespäichert ze ginn däerf e net méi wéi @max@ Buschtawen hunn.',
	'forum_avez_selectionne' => 'Dir hutt gewielt:',
	'forum_cliquer_retour' => '<a href=\'@retour_forum@\'>Hei klicken</a> fir weider.',
	'forum_forum' => 'Forum',
	'forum_info_modere' => 'Dëse Forum ass "à priori" moderéiert: äre Beitrag geet eréischt verëffentlecht wann e vun engem Administrateur vum Site bestätegt ass.',
	'forum_lien_hyper' => 'Link',
	'forum_message' => 'Äre Message',
	'forum_message_definitif' => 'Definitive Message: op de Site schécken',
	'forum_message_trop_long' => 'Äre Message ass ze laang. D’maximal Gréisst ass 20.000 Buschtawen.',
	'forum_ne_repondez_pas' => 'Äntwert net op dësen Email mais am Forum op dëser Adress:',
	'forum_page_url' => '(Wann äre Message sech op en Artikel vum Internet bezitt oder op eng Säit déi méi Informatiounen gëtt, kënnt dir hei den Titel an d’Adress vun der Säit uginn.)',
	'forum_permalink' => 'Permalink op de Kommentar',
	'forum_poste_par' => 'Message geschéckt vun @parauteur@ als Folleg vum Artikel "@titre@".', # MODIF
	'forum_qui_etes_vous' => 'Wie sidd Dir?',
	'forum_saisie_texte_info' => 'Dëse Formulär akzeptéiert SPIP-Ofkierzungen <code>[->url] {{fett}} {schräg} <quote> <code></code> an den HTML-Code <code><q> <del> <ins></code>. Fir nei Abschnitter, loosst eidel Zeilen.',
	'forum_texte' => 'Text vun ärem Message',
	'forum_titre' => 'Titel',
	'forum_url' => 'Äre Website',
	'forum_valider' => 'Är Wiel bestätegen',
	'forum_voir_avant' => 'Virschau',
	'forum_votre_email' => 'Är Email-Adress',
	'forum_votre_nom' => 'Äre Numm',
	'forum_vous_enregistrer' => 'Fir bei dësem Forum matzemaachen, muss dir Iech fir d’éischt umellen. Gidd hei är perséinlech Identifikatioun un déi der krut. Wann dir net ugemellt sidd, da musst dir',
	'forum_vous_inscrire' => 'Iech aschreiwen.',

	// I
	'icone_bruler_message' => 'Als Spam mellen',
	'icone_bruler_messages' => 'Als Spam mellen',
	'icone_legitimer_message' => 'Als kee Spam mellen',
	'icone_poster_message' => 'Message schécken',
	'icone_suivi_forum' => 'Den ëffentlechen Forum verfollegen: @nb_forums@ Beiträg',
	'icone_suivi_forums' => 'Forume verfollegen',
	'icone_supprimer_message' => 'Dëse Message läschen',
	'icone_supprimer_messages' => 'Dës Message läschen',
	'icone_valider_message' => 'Dëse Message bestätegen',
	'icone_valider_messages' => 'Dës Message bestätegen',
	'icone_valider_repondre_message' => 'Bestätegen an op dëse Message äntweren',
	'info_1_message_forum' => '1 Message am Forum',
	'info_activer_forum_public' => 'Fir déi ëffentlech Forumen anzeschalten, wielt d’Moderatiouns-Method:',
	'info_appliquer_choix_moderation' => 'Dës Moderatiouns-Method benotzen:',
	'info_config_forums_prive' => 'Am privaten Deel vum Site kënnt dir e puer Forumen aschalten:',
	'info_config_forums_prive_admin' => 'E reservéierte Forum fir d’Administrateure vum Site:',
	'info_config_forums_prive_global' => 'E globale Forum fir all Redakteren:',
	'info_config_forums_prive_objets' => 'E Forum ënnert all Artikel, Kuerzmeldung, verlinkte Site, asw.:',
	'info_desactiver_forum_public' => 'Déi ëffentlech Forumen ausschalten. Ëffentlech Forume kënne vu Fall zu Fall pro Artikel ageschalt ginn; awer net op de Rubriken, Kuerzmeldungen, asw.',
	'info_envoi_forum' => 'D’Forum-Messagen un d’Auteuren vun den Artikele schécken',
	'info_fonctionnement_forum' => 'Fonctionnement vum Forum:',
	'info_forums_liees_mot' => 'Forum-Messagen déi mat dësem Wuert verbonne sinn',
	'info_gauche_suivi_forum_2' => 'D’Säit <i>Forume verfollegen</i> ass fir d’Gestioun vum Forum a net fir ze diskutéieren oder ze schreiwen. Si weist all d’Beiträg vun de Forume vum Site, déi ëffentlech an déi privat, an dir kënnt d’Beiträg beaarbechten.',
	'info_liens_syndiques_3' => 'Forumen',
	'info_liens_syndiques_4' => 'sinn',
	'info_liens_syndiques_5' => 'Forum',
	'info_liens_syndiques_6' => 'ass',
	'info_liens_syndiques_7' => 'waarden op d’Bestätegung',
	'info_liens_texte' => 'Linken aus dem Text vum Message',
	'info_liens_titre' => 'Linken aus dem Titel vum Message',
	'info_mode_fonctionnement_defaut_forum_public' => 'Default-Méthod vun den ëffentleche Forumen',
	'info_nb_messages_forum' => '@nb@ Messagen am Forum',
	'info_option_email' => 'Wann e Visiteur vum Site e neie Message an de Forum vun engem Artikel schéckt, kennen d’Auteuren vum Artikel via Email Bescheed kréien. Wëllt dir dës Optioun benotzen?',
	'info_pas_de_forum' => 'kee Forum',
	'info_question_visiteur_ajout_document_forum' => 'Wann dir de Visiteuren erlaabt Dokumenter (Biller, Toun...) bei Forum-Message bäizeflécken, da gitt hei d’Lëscht vun den Extensiounen un déi erlaabt sinn (z.B.: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Wann dir all Type wëllt erlaben déi SPIP als sécher ukuckt, dann gitt e Stär an. Fir näischt ze erlaben, gitt näischt an.',
	'info_selectionner_message' => 'Message wielen:',
	'interface_formulaire' => 'Formulär-Interface',
	'interface_onglets' => 'Interface mat Tabs',
	'item_activer_forum_administrateur' => 'De Forum vun den Adminstrateuren aschalten',
	'item_config_forums_prive_global' => 'De Redaktor-Forum aschalten',
	'item_config_forums_prive_objets' => 'Forumen aschalten',
	'item_desactiver_forum_administrateur' => 'De Forum vun den Administrateuren ofschalten',
	'item_non_config_forums_prive_global' => 'De Redaktor-Forum ofschalten',
	'item_non_config_forums_prive_objets' => 'Forumen ofschalten',

	// L
	'label_selectionner' => 'Wielen:',
	'lien_reponse_article' => 'Äntwert op den Artikel',
	'lien_reponse_breve_2' => 'Äntwert op d’Kuerzmeldung',
	'lien_reponse_message' => 'Op de Message äntweren',
	'lien_reponse_rubrique' => 'Äntwert op d’Rubrik',
	'lien_reponse_site_reference' => 'Äntwert op de verlinkte Site',
	'lien_vider_selection' => 'Näischt auswielen',

	// M
	'messages_aucun' => 'Keen',
	'messages_meme_auteur' => 'All d’Message vun dësem Auteur',
	'messages_meme_email' => 'All d’Message vun dësem Email',
	'messages_meme_ip' => 'All d’Message vun dëser IP',
	'messages_off' => 'Geläscht',
	'messages_perso' => 'Perséinlech',
	'messages_privadm' => 'Administrateuren',
	'messages_prive' => 'Privat',
	'messages_privoff' => 'Geläscht',
	'messages_privrac' => 'Generell',
	'messages_prop' => 'Virgeschloen',
	'messages_publie' => 'Verëffentlecht',
	'messages_spam' => 'Spam',
	'messages_tous' => 'All',

	// O
	'onglet_messages_internes' => 'Intern Messagen',
	'onglet_messages_publics' => 'Ëffentlech Messagen',
	'onglet_messages_vide' => 'Messagen ouni Text',

	// R
	'repondre_message' => 'Op dëse Message äntweren',

	// S
	'statut_off' => 'Geläscht',
	'statut_original' => 'Original',
	'statut_prop' => 'Virgeschloen',
	'statut_publie' => 'Verëffentlecht',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Zeckt net är Meenung am Forum vun dësem Artikel ze soën (ënnen op der Säit).',
	'texte_en_cours_validation' => 'Dës Inhalter waarden op Bestätegung.',
	'texte_en_cours_validation_forum' => 'Sot är Meenung am Forum deen dozou gehéiert.',
	'texte_messages_publics' => 'Ëffentlech Messagen op:',
	'titre_cadre_forum_administrateur' => 'Privat-Forum vun den Administrateuren',
	'titre_cadre_forum_interne' => 'Interne Forum',
	'titre_config_forums_prive' => 'Forume vum privaten Deel',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Beaarbechte vun de Forumen',
	'titre_page_forum_suivi' => 'Beaarbechte vun de Forumen',
	'titre_selection_action' => 'Auswiel',
	'tout_voir' => 'Alles gesinn',

	// V
	'voir_messages_objet' => 'd’Message gesinn'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_lb.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_message_forum' => 'Kee Message am Forum',

	// B
	'bouton_radio_articles_futurs' => 'nëmmen fir nei Artikelen (keng Aktioun op d’Datebank).',
	'bouton_radio_articles_tous' => 'fir all nei Artikelen ouni Ausnahm.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'fir all Artikelen, ausser déi wou de Forum ausgeschalt ass.',
	'bouton_radio_enregistrement_obligatoire' => 'Obligatorescht Aschreiwen (d’Benotzer mussen sech umellen andeem si hier Email-Adress uginn ier se hier Message kënne schécken).',
	'bouton_radio_moderation_priori' => 'Moderatioun à priori (d’Message ginn eréischt verëffentlecht nodeems se vun engem Administrateur bestätegt goufen).',
	'bouton_radio_modere_abonnement' => 'op Abonnement',
	'bouton_radio_modere_posteriori' => 'Moderatioun à posteriori',
	'bouton_radio_modere_priori' => 'Moderatioun à priori',
	'bouton_radio_publication_immediate' => 'Direkt Verëffentlechung vun de Messagen (d’Message ginn direkt nom Schécken siichtbar, d’Administrateure kënnen se duerno läschen).',

	// D
	'documents_interdits_forum' => 'Dokumenter sinn am Forum net erlaabt',

	// E
	'erreur_enregistrement_message' => 'Äre Message konnt duerch en technesche Problem net gespäichert ginn',

	// F
	'form_pet_message_commentaire' => 'E Message, e Kommentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Dir hutt keen Zougang méi zu dëse Forumen.',
	'forum_attention_dix_caracteres' => '<b>Opgepasst!</b> Äre Message muss op mannst 10 Buschtawen hunn.',
	'forum_attention_message_non_poste' => 'Opgepasst, dir hutt äre Message net fortgeschéckt!',
	'forum_attention_nb_caracteres_mini' => '<b>Opgepasst!</b> Äre Message muss mindestens @min@ Buschtawen hunn.',
	'forum_attention_trois_caracteres' => '<b>Opgepasst!</b> Ären Titel muss op mannst 3 Buschtawen hunn.',
	'forum_attention_trop_caracteres' => '<b>Opgepasst!</b> Äre Message ass ze laang (@compte@ Buschtawen). Fir gespäichert ze ginn däerf e net méi wéi @max@ Buschtawen hunn.',
	'forum_avez_selectionne' => 'Dir hutt gewielt:',
	'forum_cliquer_retour' => '<a href=\'@retour_forum@\'>Hei klicken</a> fir weider.',
	'forum_forum' => 'Forum',
	'forum_info_modere' => 'Dëse Forum ass "à priori" moderéiert: äre Beitrag geet eréischt verëffentlecht wann e vun engem Administrateur vum Site bestätegt ass.',
	'forum_lien_hyper' => 'Link',
	'forum_message' => 'Äre Message',
	'forum_message_definitif' => 'Definitive Message: op de Site schécken',
	'forum_message_trop_long' => 'Äre Message ass ze laang. D’maximal Gréisst ass 20.000 Buschtawen.',
	'forum_ne_repondez_pas' => 'Äntwert net op dësen Email mais am Forum op dëser Adress:',
	'forum_page_url' => '(Wann äre Message sech op en Artikel vum Internet bezitt oder op eng Säit déi méi Informatiounen gëtt, kënnt dir hei den Titel an d’Adress vun der Säit uginn.)',
	'forum_permalink' => 'Permalink op de Kommentar',
	'forum_poste_par' => 'Message geschéckt vun @parauteur@ als Folleg vum Artikel "@titre@".', # MODIF
	'forum_qui_etes_vous' => 'Wie sidd Dir?',
	'forum_saisie_texte_info' => 'Dëse Formulär akzeptéiert SPIP-Ofkierzungen <code>[->url] {{fett}} {schräg} <quote> <code></code> an den HTML-Code <code><q> <del> <ins></code>. Fir nei Abschnitter, loosst eidel Zeilen.',
	'forum_texte' => 'Text vun ärem Message',
	'forum_titre' => 'Titel',
	'forum_url' => 'Äre Website',
	'forum_valider' => 'Är Wiel bestätegen',
	'forum_voir_avant' => 'Virschau',
	'forum_votre_email' => 'Är Email-Adress',
	'forum_votre_nom' => 'Äre Numm',
	'forum_vous_enregistrer' => 'Fir bei dësem Forum matzemaachen, muss dir Iech fir d’éischt umellen. Gidd hei är perséinlech Identifikatioun un déi der krut. Wann dir net ugemellt sidd, da musst dir',
	'forum_vous_inscrire' => 'Iech aschreiwen.',

	// I
	'icone_bruler_message' => 'Als Spam mellen',
	'icone_bruler_messages' => 'Als Spam mellen',
	'icone_legitimer_message' => 'Als kee Spam mellen',
	'icone_poster_message' => 'Message schécken',
	'icone_suivi_forum' => 'Den ëffentlechen Forum verfollegen: @nb_forums@ Beiträg',
	'icone_suivi_forums' => 'Forume verfollegen',
	'icone_supprimer_message' => 'Dëse Message läschen',
	'icone_supprimer_messages' => 'Dës Message läschen',
	'icone_valider_message' => 'Dëse Message bestätegen',
	'icone_valider_messages' => 'Dës Message bestätegen',
	'icone_valider_repondre_message' => 'Bestätegen an op dëse Message äntweren',
	'info_1_message_forum' => '1 Message am Forum',
	'info_activer_forum_public' => 'Fir déi ëffentlech Forumen anzeschalten, wielt d’Moderatiouns-Method:',
	'info_appliquer_choix_moderation' => 'Dës Moderatiouns-Method benotzen:',
	'info_config_forums_prive' => 'Am privaten Deel vum Site kënnt dir e puer Forumen aschalten:',
	'info_config_forums_prive_admin' => 'E reservéierte Forum fir d’Administrateure vum Site:',
	'info_config_forums_prive_global' => 'E globale Forum fir all Redakteren:',
	'info_config_forums_prive_objets' => 'E Forum ënnert all Artikel, Kuerzmeldung, verlinkte Site, asw.:',
	'info_desactiver_forum_public' => 'Déi ëffentlech Forumen ausschalten. Ëffentlech Forume kënne vu Fall zu Fall pro Artikel ageschalt ginn; awer net op de Rubriken, Kuerzmeldungen, asw.',
	'info_envoi_forum' => 'D’Forum-Messagen un d’Auteuren vun den Artikele schécken',
	'info_fonctionnement_forum' => 'Fonctionnement vum Forum:',
	'info_forums_liees_mot' => 'Forum-Messagen déi mat dësem Wuert verbonne sinn',
	'info_gauche_suivi_forum_2' => 'D’Säit <i>Forume verfollegen</i> ass fir d’Gestioun vum Forum a net fir ze diskutéieren oder ze schreiwen. Si weist all d’Beiträg vun de Forume vum Site, déi ëffentlech an déi privat, an dir kënnt d’Beiträg beaarbechten.',
	'info_liens_syndiques_3' => 'Forumen',
	'info_liens_syndiques_4' => 'sinn',
	'info_liens_syndiques_5' => 'Forum',
	'info_liens_syndiques_6' => 'ass',
	'info_liens_syndiques_7' => 'waarden op d’Bestätegung',
	'info_liens_texte' => 'Linken aus dem Text vum Message',
	'info_liens_titre' => 'Linken aus dem Titel vum Message',
	'info_mode_fonctionnement_defaut_forum_public' => 'Default-Méthod vun den ëffentleche Forumen',
	'info_nb_messages_forum' => '@nb@ Messagen am Forum',
	'info_option_email' => 'Wann e Visiteur vum Site e neie Message an de Forum vun engem Artikel schéckt, kennen d’Auteuren vum Artikel via Email Bescheed kréien. Wëllt dir dës Optioun benotzen?',
	'info_pas_de_forum' => 'kee Forum',
	'info_question_visiteur_ajout_document_forum' => 'Wann dir de Visiteuren erlaabt Dokumenter (Biller, Toun...) bei Forum-Message bäizeflécken, da gitt hei d’Lëscht vun den Extensiounen un déi erlaabt sinn (z.B.: gif, jpg, png, mp3).',
	'info_question_visiteur_ajout_document_forum_format' => 'Wann dir all Type wëllt erlaben déi SPIP als sécher ukuckt, dann gitt e Stär an. Fir näischt ze erlaben, gitt näischt an.',
	'info_selectionner_message' => 'Message wielen:',
	'interface_formulaire' => 'Formulär-Interface',
	'interface_onglets' => 'Interface mat Tabs',
	'item_activer_forum_administrateur' => 'De Forum vun den Adminstrateuren aschalten',
	'item_config_forums_prive_global' => 'De Redaktor-Forum aschalten',
	'item_config_forums_prive_objets' => 'Forumen aschalten',
	'item_desactiver_forum_administrateur' => 'De Forum vun den Administrateuren ofschalten',
	'item_non_config_forums_prive_global' => 'De Redaktor-Forum ofschalten',
	'item_non_config_forums_prive_objets' => 'Forumen ofschalten',

	// L
	'label_selectionner' => 'Wielen:',
	'lien_reponse_article' => 'Äntwert op den Artikel',
	'lien_reponse_breve_2' => 'Äntwert op d’Kuerzmeldung',
	'lien_reponse_message' => 'Op de Message äntweren',
	'lien_reponse_rubrique' => 'Äntwert op d’Rubrik',
	'lien_reponse_site_reference' => 'Äntwert op de verlinkte Site',
	'lien_vider_selection' => 'Näischt auswielen',

	// M
	'messages_aucun' => 'Keen',
	'messages_meme_auteur' => 'All d’Message vun dësem Auteur',
	'messages_meme_email' => 'All d’Message vun dësem Email',
	'messages_meme_ip' => 'All d’Message vun dëser IP',
	'messages_off' => 'Geläscht',
	'messages_perso' => 'Perséinlech',
	'messages_privadm' => 'Administrateuren',
	'messages_prive' => 'Privat',
	'messages_privoff' => 'Geläscht',
	'messages_privrac' => 'Generell',
	'messages_prop' => 'Virgeschloen',
	'messages_publie' => 'Verëffentlecht',
	'messages_spam' => 'Spam',
	'messages_tous' => 'All',

	// O
	'onglet_messages_internes' => 'Intern Messagen',
	'onglet_messages_publics' => 'Ëffentlech Messagen',
	'onglet_messages_vide' => 'Messagen ouni Text',

	// R
	'repondre_message' => 'Op dëse Message äntweren',

	// S
	'statut_off' => 'Geläscht',
	'statut_original' => 'Original',
	'statut_prop' => 'Virgeschloen',
	'statut_publie' => 'Verëffentlecht',
	'statut_spam' => 'Spam',

	// T
	'text_article_propose_publication_forum' => 'Zeckt net är Meenung am Forum vun dësem Artikel ze soën (ënnen op der Säit).',
	'texte_en_cours_validation' => 'Dës Inhalter waarden op Bestätegung.',
	'texte_en_cours_validation_forum' => 'Sot är Meenung am Forum deen dozou gehéiert.',
	'texte_messages_publics' => 'Ëffentlech Messagen op:',
	'titre_cadre_forum_administrateur' => 'Privat-Forum vun den Administrateuren',
	'titre_cadre_forum_interne' => 'Interne Forum',
	'titre_config_forums_prive' => 'Forume vum privaten Deel',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Beaarbechte vun de Forumen',
	'titre_page_forum_suivi' => 'Beaarbechte vun de Forumen',
	'titre_selection_action' => 'Auswiel',
	'tout_voir' => 'Alles gesinn',

	// V
	'voir_messages_objet' => 'd’Message gesinn',
];
